@@ -58,7 +58,7 @@ class Exceptions:
 
 class FISClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html)
     """
 
@@ -74,7 +74,7 @@ class FISClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#can_paginate)
         """
 
@@ -86,13 +86,13 @@ class FISClient(BaseClient):
         stopConditions: Sequence["CreateExperimentTemplateStopConditionInputTypeDef"],
         actions: Mapping[str, "CreateExperimentTemplateActionInputTypeDef"],
         roleArn: str,
-        targets: Mapping[str, "CreateExperimentTemplateTargetInputTypeDef"] = None,
-        tags: Mapping[str, str] = None
+        targets: Mapping[str, "CreateExperimentTemplateTargetInputTypeDef"] = ...,
+        tags: Mapping[str, str] = ...
     ) -> CreateExperimentTemplateResponseTypeDef:
         """
         Creates an experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.create_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.create_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#create_experiment_template)
         """
 
@@ -100,21 +100,21 @@ class FISClient(BaseClient):
         """
         Deletes the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.delete_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.delete_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#delete_experiment_template)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#generate_presigned_url)
         """
 
@@ -122,7 +122,7 @@ class FISClient(BaseClient):
         """
         Gets information about the specified AWS FIS action.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.get_action)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.get_action)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#get_action)
         """
 
@@ -130,7 +130,7 @@ class FISClient(BaseClient):
         """
         Gets information about the specified experiment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.get_experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.get_experiment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#get_experiment)
         """
 
@@ -138,37 +138,37 @@ class FISClient(BaseClient):
         """
         Gets information about the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.get_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.get_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#get_experiment_template)
         """
 
     def list_actions(
-        self, *, maxResults: int = None, nextToken: str = None
+        self, *, maxResults: int = ..., nextToken: str = ...
     ) -> ListActionsResponseTypeDef:
         """
         Lists the available AWS FIS actions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.list_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.list_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_actions)
         """
 
     def list_experiment_templates(
-        self, *, maxResults: int = None, nextToken: str = None
+        self, *, maxResults: int = ..., nextToken: str = ...
     ) -> ListExperimentTemplatesResponseTypeDef:
         """
         Lists your experiment templates.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.list_experiment_templates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.list_experiment_templates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_experiment_templates)
         """
 
     def list_experiments(
-        self, *, maxResults: int = None, nextToken: str = None
+        self, *, maxResults: int = ..., nextToken: str = ...
     ) -> ListExperimentsResponseTypeDef:
         """
         Lists your experiments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.list_experiments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.list_experiments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_experiments)
         """
 
@@ -176,17 +176,17 @@ class FISClient(BaseClient):
         """
         Lists the tags for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#list_tags_for_resource)
         """
 
     def start_experiment(
-        self, *, clientToken: str, experimentTemplateId: str, tags: Mapping[str, str] = None
+        self, *, clientToken: str, experimentTemplateId: str, tags: Mapping[str, str] = ...
     ) -> StartExperimentResponseTypeDef:
         """
         Starts running an experiment from the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.start_experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.start_experiment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#start_experiment)
         """
 
@@ -194,7 +194,7 @@ class FISClient(BaseClient):
         """
         Stops the specified experiment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.stop_experiment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.stop_experiment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#stop_experiment)
         """
 
@@ -202,15 +202,15 @@ class FISClient(BaseClient):
         """
         Applies the specified tags to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str] = None) -> Dict[str, Any]:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str] = ...) -> Dict[str, Any]:
         """
         Removes the specified tags from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#untag_resource)
         """
 
@@ -218,15 +218,15 @@ class FISClient(BaseClient):
         self,
         *,
         id: str,
-        description: str = None,
-        stopConditions: Sequence["UpdateExperimentTemplateStopConditionInputTypeDef"] = None,
-        targets: Mapping[str, "UpdateExperimentTemplateTargetInputTypeDef"] = None,
-        actions: Mapping[str, "UpdateExperimentTemplateActionInputItemTypeDef"] = None,
-        roleArn: str = None
+        description: str = ...,
+        stopConditions: Sequence["UpdateExperimentTemplateStopConditionInputTypeDef"] = ...,
+        targets: Mapping[str, "UpdateExperimentTemplateTargetInputTypeDef"] = ...,
+        actions: Mapping[str, "UpdateExperimentTemplateActionInputItemTypeDef"] = ...,
+        roleArn: str = ...
     ) -> UpdateExperimentTemplateResponseTypeDef:
         """
         Updates the specified experiment template.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/fis.html#FIS.Client.update_experiment_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/fis.html#FIS.Client.update_experiment_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/client.html#update_experiment_template)
         """
