@@ -298,10 +298,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
