@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import ExperimentActionStatusType, ExperimentStatusType
 
@@ -128,9 +128,9 @@ _OptionalCreateExperimentTemplateActionInputTypeDef = TypedDict(
     "_OptionalCreateExperimentTemplateActionInputTypeDef",
     {
         "description": str,
-        "parameters": Dict[str, str],
-        "targets": Dict[str, str],
-        "startAfter": List[str],
+        "parameters": Mapping[str, str],
+        "targets": Mapping[str, str],
+        "startAfter": Sequence[str],
     },
     total=False,
 )
@@ -148,16 +148,16 @@ _RequiredCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
     {
         "clientToken": str,
         "description": str,
-        "stopConditions": List["CreateExperimentTemplateStopConditionInputTypeDef"],
-        "actions": Dict[str, "CreateExperimentTemplateActionInputTypeDef"],
+        "stopConditions": Sequence["CreateExperimentTemplateStopConditionInputTypeDef"],
+        "actions": Mapping[str, "CreateExperimentTemplateActionInputTypeDef"],
         "roleArn": str,
     },
 )
 _OptionalCreateExperimentTemplateRequestRequestTypeDef = TypedDict(
     "_OptionalCreateExperimentTemplateRequestRequestTypeDef",
     {
-        "targets": Dict[str, "CreateExperimentTemplateTargetInputTypeDef"],
-        "tags": Dict[str, str],
+        "targets": Mapping[str, "CreateExperimentTemplateTargetInputTypeDef"],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -210,9 +210,9 @@ _RequiredCreateExperimentTemplateTargetInputTypeDef = TypedDict(
 _OptionalCreateExperimentTemplateTargetInputTypeDef = TypedDict(
     "_OptionalCreateExperimentTemplateTargetInputTypeDef",
     {
-        "resourceArns": List[str],
-        "resourceTags": Dict[str, str],
-        "filters": List["ExperimentTemplateTargetInputFilterTypeDef"],
+        "resourceArns": Sequence[str],
+        "resourceTags": Mapping[str, str],
+        "filters": Sequence["ExperimentTemplateTargetInputFilterTypeDef"],
     },
     total=False,
 )
@@ -359,7 +359,7 @@ ExperimentTemplateTargetInputFilterTypeDef = TypedDict(
     "ExperimentTemplateTargetInputFilterTypeDef",
     {
         "path": str,
-        "values": List[str],
+        "values": Sequence[str],
     },
 )
 
@@ -544,7 +544,7 @@ _RequiredStartExperimentRequestRequestTypeDef = TypedDict(
 _OptionalStartExperimentRequestRequestTypeDef = TypedDict(
     "_OptionalStartExperimentRequestRequestTypeDef",
     {
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -583,7 +583,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
@@ -596,7 +596,7 @@ _RequiredUntagResourceRequestRequestTypeDef = TypedDict(
 _OptionalUntagResourceRequestRequestTypeDef = TypedDict(
     "_OptionalUntagResourceRequestRequestTypeDef",
     {
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
     total=False,
 )
@@ -613,9 +613,9 @@ UpdateExperimentTemplateActionInputItemTypeDef = TypedDict(
     {
         "actionId": str,
         "description": str,
-        "parameters": Dict[str, str],
-        "targets": Dict[str, str],
-        "startAfter": List[str],
+        "parameters": Mapping[str, str],
+        "targets": Mapping[str, str],
+        "startAfter": Sequence[str],
     },
     total=False,
 )
@@ -630,9 +630,9 @@ _OptionalUpdateExperimentTemplateRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateExperimentTemplateRequestRequestTypeDef",
     {
         "description": str,
-        "stopConditions": List["UpdateExperimentTemplateStopConditionInputTypeDef"],
-        "targets": Dict[str, "UpdateExperimentTemplateTargetInputTypeDef"],
-        "actions": Dict[str, "UpdateExperimentTemplateActionInputItemTypeDef"],
+        "stopConditions": Sequence["UpdateExperimentTemplateStopConditionInputTypeDef"],
+        "targets": Mapping[str, "UpdateExperimentTemplateTargetInputTypeDef"],
+        "actions": Mapping[str, "UpdateExperimentTemplateActionInputItemTypeDef"],
         "roleArn": str,
     },
     total=False,
@@ -686,9 +686,9 @@ _RequiredUpdateExperimentTemplateTargetInputTypeDef = TypedDict(
 _OptionalUpdateExperimentTemplateTargetInputTypeDef = TypedDict(
     "_OptionalUpdateExperimentTemplateTargetInputTypeDef",
     {
-        "resourceArns": List[str],
-        "resourceTags": Dict[str, str],
-        "filters": List["ExperimentTemplateTargetInputFilterTypeDef"],
+        "resourceArns": Sequence[str],
+        "resourceTags": Mapping[str, str],
+        "filters": Sequence["ExperimentTemplateTargetInputFilterTypeDef"],
     },
     total=False,
 )
